@@ -68,6 +68,14 @@ on_ping_activate (GtkWidget * widget, gpointer data)
 		}
 	}
 }
+void
+on_ping_toggled (GtkToggleButton *button, gpointer data)
+{
+	Netinfo *info = data;
+
+	gtk_widget_set_sensitive (info->count,
+			gtk_toggle_button_get_active (button));
+}
 
 /* Traceroute callbacks */
 void
@@ -111,24 +119,6 @@ on_netstat_activate (GtkWidget * widget, gpointer data)
 }
 
 /* Info callbacks */
-#ifdef IFCONFIG_PROGRAM
-/*void
-on_info_nic_changed (GtkEntry * entry, gpointer info)
-{
-	gchar *nic;
-
-	g_return_if_fail (info != NULL);
-
-	nic = g_strdup (gtk_entry_get_text (entry));
-
-	if (strlen (nic) > 0) {
-		info_do (nic, (Netinfo *) & info);
-	}
-
-	g_free (nic);
-}*/
-#endif
-
 void
 on_configure_button_clicked (GtkButton *button, gpointer data)
 {
@@ -209,7 +199,7 @@ on_lookup_activate (GtkWidget * widget, gpointer data)
 	if (lookup->running) {
 		lookup_stop (lookup);
 	} else {
-		if (netinfo_validate_host (lookup)) {
+		if (netinfo_validate_domain (lookup)) {
 			entry_host = GTK_ENTRY (
 				gtk_bin_get_child (GTK_BIN (lookup->host)));
 			text = g_strdup (gtk_entry_get_text (entry_host));
